# djangorestframework-hybridrouter
A router for ViewSets and View ! And with better browsable API !

***Inspired by [this topic](https://stackoverflow.com/questions/18817988/using-django-rest-frameworks-browsable-api-with-apiviews/78459183#78459183
).***